import { CSSProperties } from 'react';
import { ThemeRef } from 'treat';
import { ThemeOrAny } from 'treat/theme';
export interface ScaleTokens<T extends keyof CSSProperties> {
    [key: string]: NonNullable<CSSProperties[T]>;
}
export interface CommonTheme {
    breakpoints: readonly number[];
    shorthands: {
        [key: string]: ReadonlyArray<keyof CSSProperties>;
    };
    aliases: {
        [key: string]: keyof CSSProperties | Extract<keyof ThemeOrAny['shorthands'], string>;
    };
}
export interface RuntimeTheme extends CommonTheme {
    ref: ThemeRef;
}
export interface StaticTheme extends CommonTheme {
    scales: {
        spacing: ScaleTokens<'margin'>;
        size: ScaleTokens<'width'>;
        fontFamily: ScaleTokens<'fontFamily'>;
        fontSize: ScaleTokens<'fontSize'>;
        fontWeight: ScaleTokens<'fontWeight'>;
        lineHeight: ScaleTokens<'lineHeight'>;
        color: ScaleTokens<'color'>;
        letterSpacing: ScaleTokens<'letterSpacing'>;
        border: ScaleTokens<'border'>;
        borderWidth: ScaleTokens<'borderWidth'>;
        radius: ScaleTokens<'borderRadius'>;
        shadow: ScaleTokens<'boxShadow'>;
        opacity: ScaleTokens<'opacity'>;
        zIndex: ScaleTokens<'zIndex'>;
    };
    resolvers: {
        [key in keyof CSSProperties]: keyof StaticTheme['scales'] | keyof ThemeOrAny['scales'];
    };
}
export declare function createTheme(tokens: ThemeOrAny & StaticTheme, localDebugName?: string): RuntimeTheme;
export declare const defaultTokens: {
    readonly breakpoints: readonly [640, 768, 1024, 1280];
    readonly scales: {
        readonly spacing: {
            readonly 0: 0;
            readonly '1px': 1;
            readonly 1: ".25rem";
            readonly 2: ".5rem";
            readonly 3: ".75rem";
            readonly 4: "1rem";
            readonly 5: "1.25rem";
            readonly 6: "1.5rem";
            readonly 8: "2rem";
            readonly 10: "2.5rem";
            readonly 12: "3rem";
            readonly 16: "4rem";
            readonly 20: "5rem";
            readonly 24: "6rem";
            readonly 32: "8rem";
            readonly 40: "10rem";
            readonly 48: "12rem";
            readonly 56: "14rem";
            readonly 64: "16rem";
        };
        readonly size: {
            readonly auto: "auto";
            readonly '100%': "100%";
            readonly 0: 0;
            readonly '1px': 1;
            readonly 1: ".25rem";
            readonly 2: ".5rem";
            readonly 3: ".75rem";
            readonly 4: "1rem";
            readonly 5: "1.25rem";
            readonly 6: "1.5rem";
            readonly 8: "2rem";
            readonly 10: "2.5rem";
            readonly 12: "3rem";
            readonly 16: "4rem";
            readonly 20: "5rem";
            readonly 24: "6rem";
            readonly 32: "8rem";
            readonly 40: "10rem";
            readonly 48: "12rem";
            readonly 56: "14rem";
            readonly 64: "16rem";
        };
        readonly fontFamily: {};
        readonly fontSize: {
            [key: number]: string;
        };
        readonly fontWeight: {};
        readonly lineHeight: {
            readonly 1: 1;
            readonly tight: 1.25;
            readonly snug: 1.375;
            readonly base: 1.5;
            readonly relaxed: 1.625;
            readonly loose: 2;
        };
        readonly color: {};
        readonly letterSpacing: {
            readonly wide: ".025em";
        };
        readonly border: {};
        readonly borderWidth: {
            readonly 1: 1;
            readonly 2: 2;
            readonly 4: 4;
            readonly 8: 8;
        };
        readonly radius: {
            readonly sm: ".125rem";
            readonly md: ".25rem";
            readonly lg: ".5rem";
            readonly full: 9999;
        };
        readonly shadow: {
            readonly sm: "0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06)";
            readonly md: "0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06)";
            readonly lg: "0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05)";
            readonly xl: "0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04)";
            readonly inner: "inset 0 2px 4px 0 rgba(0, 0, 0, 0.06)";
            readonly outline: "0 0 0 3px rgba(66, 153, 225, 0.5)";
        };
        readonly opacity: {};
        readonly zIndex: {};
    };
    readonly shorthands: {
        readonly inset: readonly ["top", "right", "bottom", "left"];
        readonly insetX: readonly ["left", "right"];
        readonly insetY: readonly ["top", "bottom"];
        readonly size: readonly ["width", "height"];
        readonly paddingX: readonly ["paddingLeft", "paddingRight"];
        readonly paddingY: readonly ["paddingTop", "paddingBottom"];
        readonly marginX: readonly ["marginLeft", "marginRight"];
        readonly marginY: readonly ["marginTop", "marginBottom"];
    };
    readonly aliases: {
        readonly p: "padding";
        readonly px: "paddingX";
        readonly py: "paddingY";
        readonly pt: "paddingTop";
        readonly pr: "paddingRight";
        readonly pb: "paddingBottom";
        readonly pl: "paddingLeft";
        readonly m: "margin";
        readonly mx: "marginX";
        readonly my: "marginY";
        readonly mt: "marginTop";
        readonly mr: "marginRight";
        readonly mb: "marginBottom";
        readonly ml: "marginLeft";
        readonly bg: "background";
    };
    readonly resolvers: {
        readonly top: "spacing";
        readonly right: "spacing";
        readonly bottom: "spacing";
        readonly left: "spacing";
        readonly zIndex: "zIndex";
        readonly flexBasis: "size";
        readonly gridGap: "spacing";
        readonly gridRowGap: "spacing";
        readonly gridColumnGap: "spacing";
        readonly gap: "spacing";
        readonly rowGap: "spacing";
        readonly columnGap: "spacing";
        readonly width: "size";
        readonly minWidth: "size";
        readonly maxWidth: "size";
        readonly height: "size";
        readonly minHeight: "size";
        readonly maxHeight: "size";
        readonly padding: "spacing";
        readonly paddingTop: "spacing";
        readonly paddingRight: "spacing";
        readonly paddingBottom: "spacing";
        readonly paddingLeft: "spacing";
        readonly margin: "spacing";
        readonly marginTop: "spacing";
        readonly marginRight: "spacing";
        readonly marginBottom: "spacing";
        readonly marginLeft: "spacing";
        readonly fontFamily: "fontFamily";
        readonly fontSize: "fontSize";
        readonly fontWeight: "fontWeight";
        readonly lineHeight: "lineHeight";
        readonly color: "color";
        readonly textShadow: "shadow";
        readonly letterSpacing: "letterSpacing";
        readonly background: "color";
        readonly backgroundColor: "color";
        readonly border: "border";
        readonly borderTop: "border";
        readonly borderRight: "border";
        readonly borderBottom: "border";
        readonly borderLeft: "border";
        readonly borderColor: "color";
        readonly borderTopColor: "color";
        readonly borderRightColor: "color";
        readonly borderBottomColor: "color";
        readonly borderLeftColor: "color";
        readonly borderWidth: "borderWidth";
        readonly borderTopWidth: "borderWidth";
        readonly borderRightWidth: "borderWidth";
        readonly borderBottomWidth: "borderWidth";
        readonly borderLeftWidth: "borderWidth";
        readonly borderRadius: "radius";
        readonly borderTopLeftRadius: "radius";
        readonly borderTopRightRadius: "radius";
        readonly borderBottomRightRadius: "radius";
        readonly borderBottomLeftRadius: "radius";
        readonly outlineColor: "color";
        readonly boxShadow: "shadow";
        readonly opacity: "opacity";
    };
};
//# sourceMappingURL=theme.d.ts.map